@@ -336,8 +336,10 @@ class Ssh:
       logging.error(" '-> Suppression des fichiers distants annulee")
     return err
 
-  def find_remote_files(self, remote_path, pattern, recursive, exit_on_error):
-    sftp = self.remote.open_sftp()
+  def find_remote_files(self, remote_path, pattern, recursive, exit_on_error, sftp=None):
+    if sftp is None:
+      sftp = self.remote.open_sftp()
+
     logging.debug("[+] Recuperation de la liste des fichiers distants")
     logging.debug(f" '-> Repertoire distant: {remote_path}")
     logging.debug(f" '-> Motif: {pattern}")
@@ -355,7 +357,7 @@ class Ssh:
             remote_files.append(fname)
       if recursive:
         for directory in remote_dirs:
-          remote_files += self.find_remote_files(directory, pattern, recursive, exit_on_error)
+          remote_files += self.find_remote_files(directory, pattern, recursive, exit_on_error, sftp)
     except Exception as err:
       err_msg = f"Erreur lors de recuperation: [{err.__class__.__name__}] {err}"
       logging.warning(err_msg)
